@@ -17,27 +17,12 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "config.h"
-
 #include <atk/atkgobjectaccessible.h>
-#include <atk/atkregistry.h>
-#include <atk/atkutil.h>
 
-/**
- * SECTION:atkgobjectaccessible
- * @Short_description: This object class is derived from AtkObject and
- *  can be used as a basis implementing accessible objects.
- * @Title:AtkGObjectAccessible
- *
- * This object class is derived from AtkObject. It can be used as a
- * basis for implementing accessible objects for GObjects which are
- * not derived from GtkWidget. One example of its use is in providing
- * an accessible object for GnomeCanvasItem in the GAIL library.
- */
 static void       atk_gobject_accessible_class_init       (AtkGObjectAccessibleClass   *klass);
 static void       atk_real_gobject_accessible_initialize  (AtkObject         *atk_obj,
                                                            gpointer          data);
-static void       atk_gobject_accessible_object_gone_cb   (gpointer          data);
+static void       atk_gobject_accessible_dispose          (gpointer          data);
 
 static GQuark quark_accessible_object = 0;
 static GQuark quark_object = 0;
@@ -88,7 +73,8 @@ atk_gobject_accessible_for_object (GObject *obj)
   g_return_val_if_fail (G_IS_OBJECT (obj), NULL);
   /* See if we have a cached accessible for this object */
 
-  accessible = quark_accessible_object ? g_object_get_qdata (obj, quark_accessible_object) : NULL;
+  accessible = g_object_get_qdata (obj,
+				   quark_accessible_object);
 
   if (!accessible)
     {
@@ -145,51 +131,25 @@ atk_real_gobject_accessible_initialize (AtkObject  *atk_obj,
   atk_obj->layer = ATK_LAYER_WIDGET;
 
   g_object_weak_ref (data,
-                     (GWeakNotify) atk_gobject_accessible_object_gone_cb,
+                     (GWeakNotify) atk_gobject_accessible_dispose,
                      atk_gobj);
 }
 
 static void
-atk_gobject_accessible_object_gone_cb (gpointer  data)
+atk_gobject_accessible_dispose (gpointer  data)
 {
-  GObject *object;
-
   g_return_if_fail (ATK_IS_GOBJECT_ACCESSIBLE (data));
 
-  object = atk_gobject_accessible_get_object (data);
-  if (object)
-      g_object_set_qdata (object, quark_accessible_object, NULL);
-
   g_object_set_qdata (G_OBJECT (data), quark_object, NULL);
   atk_object_notify_state_change (ATK_OBJECT (data), ATK_STATE_DEFUNCT,
                                   TRUE); 
   g_object_unref (data);
 }
 
-static void
-atk_gobject_accessible_dispose (GObject *atk_obj)
-{
-   GObject *obj = atk_gobject_accessible_get_object (ATK_GOBJECT_ACCESSIBLE (atk_obj));
-
-   if (obj) {
-      g_object_set_qdata (obj, quark_accessible_object, NULL);
-      g_object_weak_unref (obj,
-                           (GWeakNotify) atk_gobject_accessible_object_gone_cb,
-                           atk_obj);
-
-      g_object_set_qdata (atk_obj, quark_object, NULL);
-      atk_object_notify_state_change (ATK_OBJECT (atk_obj), ATK_STATE_DEFUNCT,
-                                      TRUE); 
-   }
-
-   G_OBJECT_CLASS (parent_class)->dispose (atk_obj);
-}
-
 static void
 atk_gobject_accessible_class_init (AtkGObjectAccessibleClass *klass)
 { 
   AtkObjectClass *class;
-  GObjectClass *object_class;
 
   class = ATK_OBJECT_CLASS (klass);
 
@@ -197,9 +157,6 @@ atk_gobject_accessible_class_init (AtkGObjectAccessibleClass *klass)
 
   class->initialize = atk_real_gobject_accessible_initialize;
 
-  object_class = G_OBJECT_CLASS (klass);
-  object_class->dispose = atk_gobject_accessible_dispose;
-
   if (!quark_accessible_object)
     quark_accessible_object = g_quark_from_static_string ("accessible-object");
   quark_object = g_quark_from_static_string ("object-for-accessible");
